@@ -52,9 +52,12 @@ mod v0_19_0;
 #[cfg(feature = "v0_20_0")]
 mod v0_20_0;
 
+#[cfg(feature = "v0_21_0")]
+mod v0_21_0;
+
 // without a specified version, use latest version supported
 #[cfg(not(feature = "specific"))]
-mod v0_20_0;
+mod v0_21_0;
 
 #[cfg(feature = "v0_4_0")]
 pub use v0_4_0::*;
@@ -110,6 +113,9 @@ pub use v0_19_0::*;
 #[cfg(feature = "v0_20_0")]
 pub use v0_20_0::*;
 
+#[cfg(feature = "v0_21_0")]
+pub use v0_21_0::*;
+
 // without a specified version, use latest version supported
 #[cfg(not(feature = "specific"))]
-pub use v0_20_0::*;
+pub use v0_21_0::*;
